[llvm-commits] CVS: llvm/include/llvm/CodeGen/DwarfWriter.h
Jim Laskey
jlaskey at apple.com
Wed Jan 18 08:54:47 PST 2006
Changes in directory llvm/include/llvm/CodeGen:
DwarfWriter.h updated: 1.10 -> 1.11
---
Log message:
Added minimum Dwarf aranges. Cleaned up some section headers. Line number
support now works in gdb.
---
Diffs of the changes: (+6 -6)
DwarfWriter.h | 12 ++++++------
1 files changed, 6 insertions(+), 6 deletions(-)
Index: llvm/include/llvm/CodeGen/DwarfWriter.h
diff -u llvm/include/llvm/CodeGen/DwarfWriter.h:1.10 llvm/include/llvm/CodeGen/DwarfWriter.h:1.11
--- llvm/include/llvm/CodeGen/DwarfWriter.h:1.10 Tue Jan 17 15:39:39 2006
+++ llvm/include/llvm/CodeGen/DwarfWriter.h Wed Jan 18 10:54:26 2006
@@ -855,12 +855,12 @@
}
void EmitLabel(const char *Tag, unsigned Number) const;
/// EmitLabelReference - Emit a reference to a label.
///
- void EmitLabelReference(DWLabel Label) const {
- EmitLabelReference(Label.Tag, Label.Number);
+ void EmitReference(DWLabel Label) const {
+ EmitReference(Label.Tag, Label.Number);
}
- void EmitLabelReference(const char *Tag, unsigned Number) const;
+ void EmitReference(const char *Tag, unsigned Number) const;
/// EmitDifference - Emit the difference between two labels. Some
/// assemblers do not behave with absolute expressions with data directives,
@@ -967,11 +967,11 @@
///
void EndModule();
- /// BeginFunction - Emit pre-function debug information.
+ /// BeginFunction - Gather pre-function debug information.
///
void BeginFunction();
- /// EndFunction - Emit post-function debug information.
+ /// EndFunction - Gather and emit post-function debug information.
///
void EndFunction();
};
@@ -855,12 +855,12 @@
}
void EmitLabel(const char *Tag, unsigned Number) const;
- /// EmitLabelReference - Emit a reference to a label.
+ /// EmitReference - Emit a reference to a label.
///
More information about the llvm-commits
mailing list